/*

 File: calccontrol.h, 2003/06/17

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _CALC_H_INCLUDED
#define _CALC_H_INCLUDED

#include <qobject.h>
#include <qstring.h>

#include <vector>

#include "methods.h"
#include "optim.h"

class Calculation : public QObject
{
  Q_OBJECT

 public:

  Calculation(const std::vector<OptimData*>&,bool);
  Calculation(const std::vector<OptimData*>&,const std::vector<OptTaylData*>&,bool);
  ~Calculation();

  void start();
  void stop();

 protected:

  void timerEvent(QTimerEvent*);

 signals:

  void sendMessage(const QString&);
  void sendGarbage(const QString&);
  void sendError(const QString&);
  void activateOutputfor(const MethodBase*,const OptimResult*);
  void calcFinished(const TaylorMemory<CInterval>*);
  void calcStopped();

 private:

  //variables for branch and bound algorithm 
  OptimAlgBase *oab;
  std::vector<OptimData*> oabdat;
  OptimResult  *oabres;

  //variables for methods I-IV
  MethodBase* actMethod;

  //variables for taylororder optimization
  OptTaylOrd    *oto;
  std::vector<OptTaylData*> otodat;
  OptTaylResult *otores;

  //variable for communication with threads
  SharedData *shd;

  void setNext();
  void OptTaylReady();
  void OptimAlgReady();

  //variables for other things
  int counter, counter24;
  bool garbage;
  bool results;
  TaylorMemory<CInterval> *taylorcoeff;//variables for Taylor coefficients (output)
};

#endif

/*

  End of File: calccontrol.h

*/
