/*

 File: gui_inputwidget.h, 2004/07/29

 ACETAF, Version 3.0.0

 Copyright (C) Markus Neher, markus.neher@math.uni-karlsruhe.de
               Ingo Eble,    ingoeble@web.de

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

*/

#ifndef _INPUTWIDGET_H_INCLUDED
#define _INPUTWIDGET_H_INCLUDED

#include <qvariant.h>
#include <qframe.h>
#include <qwidget.h>
#include <qmultilineedit.h>
#include <qlineedit.h>
class QVBoxLayout; 
class QHBoxLayout; 
class QGridLayout; 
class QCheckBox;
class QGroupBox;
class QLabel;

enum {
  
  ExprEdit = 0, 
  CenterEdit = 1, 
  RadiusEdit = 2, 
  OrderTaylMeth2Edit = 3, 
  OrderTaylMeth4Edit = 4,
  PrecTayl2Edit = 5,
  PrecTayl4Edit = 6,
  OrdDeriv3Edit = 7,
  OrdDeriv4Edit = 8,
  Test2Edit = 9,
  Test4Edit = 10,
  MaxOrd2Edit = 11,
  MaxOrd4Edit = 12,
  MaxNoSeg1Edit = 13,
  MaxNoSeg2Edit = 14,
  MaxNoSeg3Edit = 15,
  MaxNoSeg4Edit = 16,
  MinNoSeg1Edit = 17,
  MinNoSeg2Edit = 18,
  MinNoSeg3Edit = 19,
  MinNoSeg4Edit = 20,
  RelErr1Edit = 21,
  RelErr2Edit = 22,
  RelErr3Edit = 23,
  RelErr4Edit = 24,
  AbsErr1Edit = 25,
  AbsErr2Edit = 26,
  AbsErr3Edit = 27,
  AbsErr4Edit = 28,
  MaxTime1Edit = 29,
  MaxTime2Edit = 30,
  MaxTime3Edit = 31,
  MaxTime4Edit = 32

};

class InputWidget : public QWidget
{ 
    Q_OBJECT

public:
    InputWidget( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~InputWidget();

    bool M1,M2,M3,M4,verbose,fixedsubdiv,optimization;

    QString Bounds() const { return Bounds_ListBox->text(); }
    QString Remainders() const { return Remainders_ListBox->text(); }
    QString Omega() const { return Omega_ListBox->text(); }
    void setBounds(const QString& s) { Bounds_ListBox->setText( s ); }
    void setRemainders(const QString& s) { Remainders_ListBox->setText( s ); }
    void setOmega(const QString& s) { Omega_ListBox->setText( s ); }

    QString LineEditValue(int i) const { return data[i]->text(); }
    bool CheckBoxValue(int) const;
    void setLineEditValue(int i, const QString& s) { data[i]->setText( s ); }
    void setCheckBoxValue(int, bool);

 private slots:

  void CheckBoxToggled();
  void disableAll();
  void activateM(int);

 public slots:

  void InputEnable(bool);

 private:
    QVBoxLayout* InputWidgetLayout;
    QGridLayout* Layout13;
    QGridLayout* DataForMethodsBoxLayout;
    QHBoxLayout* ExprBoxLayout;
    QGridLayout* MethodsBoxLayout;
    QHBoxLayout* DomainBoxLayout;
    QGridLayout* GroupBox4Layout;
    QHBoxLayout* Layout14;
    QHBoxLayout* BoundsBoxLayout;
    QHBoxLayout* RemaindersBoxLayout;
    QHBoxLayout* OmegaBoxLayout;
    bool event( QEvent* );

    QGroupBox 
      *ExprBox, 
      *MethodsBox, 
      *DomainBox, 
      *DataForMethodsBox, 
      *BoundsBox, 
      *RemaindersBox, 
      *OmegaBox;
    QLabel 
      *ExprLabel, 
      *CenterLabel, 
      *RadiusLabel, 
      *BoundsLabel, 
      *RemaindersLabel, 
      *OmegaLabel, 
      *OrderLabel, 
      *PrecisionLabel, 
      *DerivativeLabel, 
      *MaxOrderLabel, 
      *MaxCompTimeLabel, 
      *RelErrLabel, 
      *AbsErrLabel, 
      *TestLabel, 
      *Method1InputLabel, 
      *Method2InputLabel, 
      *Method3InputLabel, 
      *Method4InputLabel, 
      *MinNoSegLabel, 
      *MaxNoSegLabel;
    QLineEdit *data[33];
    QCheckBox 
      *Method1_CheckBox, 
      *Method2_CheckBox, 
      *Method3_CheckBox, 
      *Method4_CheckBox, 
      *Verbose_CheckBox, 
      *FixedSubdivCheckBox,
      *OptimizationCheckBox;
    QMultiLineEdit 
      *Bounds_ListBox, 
      *Remainders_ListBox, 
      *Omega_ListBox;
};

#endif

/*

  End of File: gui_inputwidget.h

*/
